@@ -39,9 +39,9 @@ Calendar::Calendar(QObject *parent)
 //   connect(m_dayHelper, SIGNAL(calendarChanged()), this, SLOT(updateData()));
 }
 
-QDate Calendar::displayedDate() const
+QDateTime Calendar::displayedDate() const
 {
-    return m_displayedDate;
+    return QDateTime(m_displayedDate);
 }
 
 void Calendar::setDisplayedDate(const QDate &dateTime)
@@ -67,18 +67,24 @@ void Calendar::setDisplayedDate(const QDate &dateTime)
     }
 }
 
-QDate Calendar::today() const
+void Calendar::setDisplayedDate(const QDateTime &dateTime)
 {
-    return m_today;
+    setDisplayedDate(dateTime.date());
 }
 
-void Calendar::setToday(const QDate &dateTime)
+QDateTime Calendar::today() const
 {
-    if (dateTime == m_today) {
+    return QDateTime(m_today);
+}
+
+void Calendar::setToday(const QDateTime &dateTime)
+{
+    QDate date = dateTime.date();
+    if (date == m_today) {
         return;
     }
 
-    m_today = dateTime;
+    m_today = date;
     if (m_displayedDate.isNull()) {
         resetToToday();
     } else {
@@ -103,7 +109,7 @@ int Calendar::types() const
 
 void Calendar::setTypes(int types)
 {
-    if (m_types == types) {
+    if (m_types == static_cast<Types>(types)) {
         return;
     }
 
@@ -143,7 +149,7 @@ void Calendar::setWeeks(int weeks)
 
 int Calendar::firstDayOfWeek() const
 {
-    // QML has Sunday as 0, so we need to accomodate here
+    // QML has Sunday as 0, so we need to accommodate here
     return m_firstDayOfWeek == 7 ? 0 : m_firstDayOfWeek;
 }
 
@@ -154,7 +160,7 @@ void Calendar::setFirstDayOfWeek(int day)
     }
 
     if (m_firstDayOfWeek != day) {
-        // QML has Sunday as 0, so we need to accomodate here
+        // QML has Sunday as 0, so we need to accommodate here
         // for QDate functions which have Sunday as 7
         if (day == 0) {
             m_firstDayOfWeek = 7;
@@ -180,7 +186,7 @@ int Calendar::currentWeek() const
 
 QString Calendar::dayName(int weekday) const
 {
-    return QDate::shortDayName(weekday);
+    return QLocale::system().dayName(weekday, QLocale::ShortFormat);
 }
 
 QString Calendar::monthName() const
@@ -193,9 +199,12 @@ QString Calendar::monthName() const
     // locale and take the month name from that.
     //
     // See https://bugs.kde.org/show_bug.cgi?id=353715
-    const QString lang = QLocale().uiLanguages().at(0);
-    // If lang is empty, it will create just a system locale
-    QLocale langLocale(lang);
+
+    QLocale langLocale;
+
+    if (QLocale().uiLanguages().length() > 0) {
+        langLocale = QLocale(QLocale().uiLanguages().at(0));
+    }
     return langLocale.standaloneMonthName(m_displayedDate.month());
 }
 
